@@ -1,4 +1,5 @@
 from interpolatepy.cubic_spline import CubicSpline
+import matplotlib.pyplot as plt
 
 
 # Example usage
@@ -12,3 +13,4 @@ if __name__ == "__main__":
 
     # Plot the trajectory
     spline.plot(1000)
+    plt.show()
